@@ -395,7 +395,7 @@ class Project(object):
         #   https://www.gnu.org/software/bash/manual/html_node/Double-Quotes.html
         #   http://www.tldp.org/LDP/abs/html/special-chars.html#FIELDREF
         #   https://github.com/torvalds/linux/blob/2bfe01ef/include/uapi/linux/binfmts.h#L18
-        return re.sub(r'[ $`!*@"\\\r\n\t]', "_", name)[0:42]
+        return re.sub(r'[ &$`!*@"()\[\]\\\r\n\t]', "_", name)[0:42]
 
     def _get_virtualenv_hash(self, name):
         # type: (str) -> str
@@ -726,7 +726,7 @@ class Project(object):
         if not self.pipfile_exists:
             return True
 
-        if not len(self.read_pipfile()):
+        if not self.read_pipfile():
             return True
 
         return False
@@ -821,8 +821,10 @@ class Project(object):
         from .vendor.plette.lockfiles import PIPFILE_SPEC_CURRENT
         if self.lockfile_exists:
             sources = self.lockfile_content.get("_meta", {}).get("sources", [])
-        else:
+        elif "source" in self.parsed_pipfile:
             sources = [dict(source) for source in self.parsed_pipfile["source"]]
+        else:
+            sources = self.pipfile_sources
         if not isinstance(sources, list):
             sources = [sources]
         return {
